==> deverhood-react-1.16.51.tgz: package/src/reducers/his.js <==
import { HIS_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  inventories: [],
  inventory: {},
  distributionUnits: [],
  lots: [],
  lot: {},
  medications: [],
  medication: [],
  invoices: [],
  invoice: {}
};
export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case HIS_API.INVENTORY.ALL.SUCCESS:
      return reducer.list("inventories");
    case HIS_API.INVENTORY.GET.SUCCESS:
      return { ...reducer.get("inventory"), lots: action.data.purchases };
    case HIS_API.INVENTORY.POST.SUCCESS:
      return reducer.post("inventories");
    case HIS_API.INVENTORY.PUT.SUCCESS:
      return reducer.put("inventory", "inventories");
    case HIS_API.INVENTORY.DEL.SUCCESS:
      return {
        ...state,
        inventories: state.inventories.filter(v => v.id !== action.data),
        inventory: {}
      };
    case HIS_API.INVENTORY.CLEAR.SUCCESS:
      return { ...state, inventories: [], inventory: {} };
    case HIS_API.UNIT.ALL.SUCCESS:
      return reducer.list("distributionUnits");
    case HIS_API.LOTS.POST.SUCCESS:
      return reducer.post("lots");
    case HIS_API.LOTS.PUT.SUCCESS:
      return reducer.post("lot", "lots");
    case HIS_API.LOTS.DEL.SUCCESS:
      return reducer.delete("lots");
    case HIS_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case HIS_API.SELF.GET.SUCCESS:
      return reducer.get();
    case HIS_API.SELF.POST.SUCCESS:
      return reducer.post();
    case HIS_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case HIS_API.MEDICATION.ALL.SUCCESS:
      return reducer.list("medications");
    case HIS_API.MEDICATION.GET.SUCCESS:
      return reducer.get("medication");
    case HIS_API.MEDICATION.POST.SUCCESS:
      return reducer.post("medications");
    case HIS_API.MEDICATION.PUT.SUCCESS:
      return reducer.put("medication", "medications");
    case HIS_API.MEDICATION.DEL.SUCCESS:
      return reducer.delete("medications");
    case HIS_API.INVOICE.ALL.SUCCESS:
      return reducer.list("invoices");
    case HIS_API.INVOICE.GET.SUCCESS:
      return reducer.get("invoice");
    case HIS_API.INVOICE.POST.SUCCESS:
      return reducer.post("invoices");
    case HIS_API.INVOICE.PUT.SUCCESS:
      return reducer.put("invoice", "invoices");
    case HIS_API.INVOICE.DEL.SUCCESS:
      return reducer.delete("invoices");
    default:
      return state;
  }
};

==> deverhood-react-1.16.59.tgz: package/src/reducers/his.js <==
import { HIS_API } from "../actions/actionType";
import Super from "./super";
import moment from "moment";
const defaultState = {
  list: [],
  data: {},
  inventories: [],
  inventory: {},
  distributionUnits: [],
  lots: [],
  lot: {},
  medications: [],
  medication: [],
  invoices: [],
  invoice: {}
};
export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case HIS_API.INVENTORY.ALL.SUCCESS:
      return reducer.list("inventories");
    case HIS_API.INVENTORY.GET.SUCCESS:
      return { ...reducer.get("inventory"), lots: action.data.purchases };
    case HIS_API.INVENTORY.POST.SUCCESS:
      return reducer.post("inventories");
    case HIS_API.INVENTORY.PUT.SUCCESS:
      return reducer.put("inventory", "inventories");
    case HIS_API.INVENTORY.DEL.SUCCESS:
      return {
        ...state,
        inventories: state.inventories.filter(v => v.id !== action.data),
        inventory: {}
      };
    case HIS_API.INVENTORY.CLEAR.SUCCESS:
      return { ...state, inventories: [], inventory: {} };
    case HIS_API.UNIT.ALL.SUCCESS:
      return reducer.list("distributionUnits");
    case HIS_API.LOTS.POST.SUCCESS:
      return reducer.post("lots");
    case HIS_API.LOTS.PUT.SUCCESS:
      return reducer.put("lot", "lots");
    case HIS_API.LOTS.DEL.SUCCESS:
      return reducer.delete("lots");
    case HIS_API.SELF.ALL.SUCCESS:
      return reducer.list();
    case HIS_API.SELF.GET.SUCCESS:
      return reducer.get();
    case HIS_API.SELF.POST.SUCCESS:
      return reducer.post();
    case HIS_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case HIS_API.MEDICATION.ALL.SUCCESS:
      return reducer.list("medications");
    case HIS_API.MEDICATION.GET.SUCCESS:
      return reducer.get("medication");
    case HIS_API.MEDICATION.POST.SUCCESS:
      return reducer.push("medications");
    case HIS_API.MEDICATION.PUT.SUCCESS:
      return reducer.put("medication", "medications");
    case HIS_API.MEDICATION.DEL.SUCCESS:
      return reducer.delete("medications");
    case HIS_API.INVOICE.ALL.SUCCESS:
      return reducer.list("invoices");
    case HIS_API.INVOICE.GET.SUCCESS:
      return reducer.get("invoice");
    case HIS_API.INVOICE.POST.SUCCESS:
      return reducer.post("invoices");
    case HIS_API.INVOICE.PUT.SUCCESS:
      return reducer.put("invoice", "invoices");
    case HIS_API.INVOICE.DEL.SUCCESS:
      return reducer.delete("invoices");
    default:
      return state;
  }
};
